/*
 * Created by Aaron Lerch (2005)
 * Contact me at aaronlerch@yahoo.com
 */

using System;
using System.Text;

namespace Lerch.X10
{
    public class X10Command
    {
        private HouseCode houseCode;
        private UnitCode unitCode;
        private Commands command;
        private int level;

        /// <summary>
        /// Default constructor, no options set
        /// </summary>
        public X10Command()
        {
        }

        /// <summary>
        /// Set defaults at creation time
        /// </summary>
        /// <param name="house">House Code</param>
        /// <param name="unit">Unit Code</param>
        /// <param name="command">Command to execute</param>
        /// <param name="level">Dim/Bright level (optional)</param>
        public X10Command(HouseCode house, UnitCode unit, Commands command, int level)
        {
            this.HouseCode = house;
            this.UnitCode = unit;
            this.Command = command;
            this.Level = level;
        }

        /// <summary>
        /// Copy an existing X10Command object
        /// </summary>
        /// <param name="source">Source object to copy parameters from</param>
        public X10Command(X10Command source)
        {
            this.HouseCode = source.HouseCode;
            this.UnitCode = source.UnitCode;
            this.Command = source.Command;
            this.Level = source.Level;
        }

        /// <summary>
        /// House code reference of X10 device
        /// </summary>
        public HouseCode HouseCode
        {
            get
            {
                return houseCode;
            }
            set
            {
                houseCode = value;
            }
        }

        /// <summary>
        /// Unit code reference of X10 device
        /// </summary>
        public UnitCode UnitCode
        {
            get
            {
                return unitCode;
            }
            set
            {
                unitCode = value;
            }
        }

        /// <summary>
        /// Command to execute
        /// </summary>
        public Commands Command
        {
            get
            {
                return command;
            }
            set
            {
                command = value;
            }
        }

        /// <summary>
        /// Dim level to set (rounds down to the nearest multiple of 5)
        /// </summary>
        public int Level
        {
            get
            {
                return level;
            }
            set
            {
                // Round down to the nearest multiple of 5, between 0 and 100 (representing percent)
                if (value <= 0)
                {
                    level = 0;
                }
                else if (value >= 100)
                {
                    level = 100;
                }
                else
                {
                    level = value - (value % 5);
                }
            }
        }
    }
}
